@@ -37,7 +37,10 @@ class Exchange2010Service(ExchangeServiceSOAP):
     return Exchange2010FolderService(service=self)
 
   def _send_soap_request(self, body, headers=None, retries=2, timeout=30, encoding="utf-8"):
-    headers = [("Accept", "text/xml"), ("Content-type", "text/xml; charset=%s " % encoding)]
+    headers = {
+      "Accept" : "text/xml",
+      "Content-type" : "text/xml; charset=%s " % encoding
+    }
     return super(Exchange2010Service, self)._send_soap_request(body, headers=headers, retries=retries, timeout=timeout, encoding=encoding)
 
   def _check_for_errors(self, xml_tree):
@@ -85,22 +88,121 @@ class Exchange2010CalendarService(BaseExchangeCalendarService):
   def new_event(self, **properties):
     return Exchange2010CalendarEvent(service=self.service, calendar_id=self.calendar_id, **properties)
 
+  def list_events(self, start=None, end=None, details=False):
+    return Exchange2010CalendarEventList(service=self.service, start=start, end=end, details=details)
+
+
+class Exchange2010CalendarEventList(object):
+  """
+  Creates & Stores a list of Exchange2010CalendarEvent items in the "self.events" variable.
+  """
+  def __init__(self, service=None, start=None, end=None, details=False):
+    self.service = service
+    self.count = 0
+    self.start = start
+    self.end = end
+    self.events = list()
+    self.event_ids = list()
+    self.details = details
+
+    # This request uses a Calendar-specific query between two dates.
+    body = soap_request.get_calendar_items(format=u'AllProperties', start=self.start, end=self.end)
+    response_xml = self.service.send(body)
+    self._parse_response_for_all_events(response_xml)
+
+    # Populate the event ID list, for convenience reasons.
+    for event in self.events:
+      self.event_ids.append(event._id)
+
+    # If we have requested all the details, basically repeat the previous 3 steps,
+    # but instead of start/stop, we have a list of ID fields.
+    if self.details:
+      log.debug(u'Received request for all details, retrieving now!')
+      self.load_all_details()
+    return
+
+  def _parse_response_for_all_events(self, response):
+    """
+    This function will retrieve *most* of the event data, excluding Organizer & Attendee details
+    """
+    calendar_items = response.xpath(u'//t:CalendarItem', namespaces=soap_request.NAMESPACES)
+    counter = 0
+    if calendar_items:
+      self.count = len(calendar_items)
+      log.debug(u'Found %s items' % self.count)
+      
+      for item in calendar_items:
+        # Skip matches of CalendarItem that are contained within other CalenderItems, particularly
+        # the fact that "<CalendarItem>" tags are located within "<ConflictingMeetings>"
+        if item.getparent().tag.endswith('ConflictingMeetings'):
+          continue
+
+        self._add_event(xml=item)
+    else:
+      log.debug(u'No calendar items found with search parameters.')
+
+    return self
+  
+  def _add_event(self, xml=None):
+    log.debug(u'Adding new event to all events list.')
+    event = Exchange2010CalendarEvent(service=self.service, xml=xml)
+    log.debug(u'Subject of new event is %s' % event.subject)
+    self.events.append(event)
+    return self
+
+  def load_all_details(self):
+    """
+    This function will execute all the event lookups for known events.
+
+    This is intended for use when you want to have a completely populated event entry, including
+    Organizer & Attendee details.
+    """
+    log.debug(u"Loading all details")
+    if self.count > 0:
+      # Now, empty out the events to prevent duplicates!
+      del(self.events[:])
+      
+      # Send the SOAP request with the list of exchange ID values.
+      log.debug(u"Requesting all event details for events: {event_list}".format(event_list=str(self.event_ids)))
+      body = soap_request.get_item(exchange_id=self.event_ids, format=u'AllProperties')
+      response_xml = self.service.send(body)
+
+      # Re-parse the results for all the details!
+      self._parse_response_for_all_events(response_xml)
+    
+    return self
+
 
 class Exchange2010CalendarEvent(BaseExchangeCalendarEvent):
 
   def _init_from_service(self, id):
-
+    log.debug(u'Creating new Exchange2010CalendarEvent object from ID')
+    self.xpath_root = u'//m:Items/t:CalendarItem'
     body = soap_request.get_item(exchange_id=id, format=u'AllProperties')
     response_xml = self.service.send(body)
     properties = self._parse_response_for_get_event(response_xml)
 
     self._update_properties(properties)
     self._id = id
+    log.debug(u'Created new event object with ID: %s' % self._id)
 
     self._reset_dirty_attributes()
 
     return self
 
+  def _init_from_xml(self, xml=None):
+    log.debug(u'Creating new Exchange2010CalendarEvent object from XML')
+    self.xpath_root = u'.'
+    properties = self._parse_event_properties(xml)
+
+    self._update_properties(properties)
+    self._id = xml.xpath(u'./t:ItemId/@Id', namespaces=soap_request.NAMESPACES)[0]
+
+    log.debug(u'Created new event object with ID: %s' % self._id)
+    self._reset_dirty_attributes()
+
+    return self
+
   def as_json(self):
     raise NotImplementedError
 
@@ -275,22 +377,22 @@ class Exchange2010CalendarEvent(BaseExchangeCalendarEvent):
   def _parse_event_properties(self, response):
 
     property_map = {
-      u'subject'      : { u'xpath' : u'//m:Items/t:CalendarItem/t:Subject'},  # noqa
-      u'location'     : { u'xpath' : u'//m:Items/t:CalendarItem/t:Location'},  # noqa
-      u'availability' : { u'xpath' : u'//m:Items/t:CalendarItem/t:LegacyFreeBusyStatus'},  # noqa
-      u'start'        : { u'xpath' : u'//m:Items/t:CalendarItem/t:Start', u'cast': u'datetime'},  # noqa
-      u'end'          : { u'xpath' : u'//m:Items/t:CalendarItem/t:End', u'cast': u'datetime'},  # noqa
-      u'html_body'    : { u'xpath' : u'//m:Items/t:CalendarItem/t:Body[@BodyType="HTML"]'},  # noqa
-      u'text_body'    : { u'xpath' : u'//m:Items/t:CalendarItem/t:Body[@BodyType="Text"]'},  # noqa
-      u'reminder_minutes_before_start'  : { u'xpath' : u'//m:Items/t:CalendarItem/t:ReminderMinutesBeforeStart', u'cast': u'int'},  # noqa
-      u'is_all_day'   : { u'xpath' : u'//m:Items/t:CalendarItem/t:IsAllDayEvent', u'cast': u'bool'},  # noqa
+      u'subject'      : { u'xpath' : self.xpath_root + u'/t:Subject'},  # noqa
+      u'location'     : { u'xpath' : self.xpath_root + u'/t:Location'},  # noqa
+      u'availability' : { u'xpath' : self.xpath_root + u'/t:LegacyFreeBusyStatus'},  # noqa
+      u'start'        : { u'xpath' : self.xpath_root + u'/t:Start', u'cast': u'datetime'},  # noqa
+      u'end'          : { u'xpath' : self.xpath_root + u'/t:End', u'cast': u'datetime'},  # noqa
+      u'html_body'    : { u'xpath' : self.xpath_root + u'/t:Body[@BodyType="HTML"]'},  # noqa
+      u'text_body'    : { u'xpath' : self.xpath_root + u'/t:Body[@BodyType="Text"]'},  # noqa
+      u'reminder_minutes_before_start'  : { u'xpath' : self.xpath_root + u'/t:ReminderMinutesBeforeStart', u'cast': u'int'},  # noqa
+      u'is_all_day'   : { u'xpath' : self.xpath_root + u'/t:IsAllDayEvent', u'cast': u'bool'},  # noqa
     }
 
     return self.service._xpath_to_dict(element=response, property_map=property_map, namespace_map=soap_request.NAMESPACES)
 
   def _parse_event_organizer(self, response):
 
-    organizer = response.xpath(u'//m:Items/t:CalendarItem/t:Organizer/t:Mailbox', namespaces=soap_request.NAMESPACES)
+    organizer = response.xpath(self.xpath_root + u'/t:Organizer/t:Mailbox', namespaces=soap_request.NAMESPACES)
 
     property_map = {
       u'name'      : { u'xpath' : u't:Name'},  # noqa
@@ -312,7 +414,7 @@ class Exchange2010CalendarEvent(BaseExchangeCalendarEvent):
 
     result = []
 
-    resources = response.xpath(u'//m:Items/t:CalendarItem/t:Resources/t:Attendee', namespaces=soap_request.NAMESPACES)
+    resources = response.xpath(self.xpath_root + u'/t:Resources/t:Attendee', namespaces=soap_request.NAMESPACES)
 
     for attendee in resources:
       attendee_properties = self.service._xpath_to_dict(element=attendee, property_map=property_map, namespace_map=soap_request.NAMESPACES)
@@ -336,7 +438,7 @@ class Exchange2010CalendarEvent(BaseExchangeCalendarEvent):
 
     result = []
 
-    required_attendees = response.xpath(u'//m:Items/t:CalendarItem/t:RequiredAttendees/t:Attendee', namespaces=soap_request.NAMESPACES)
+    required_attendees = response.xpath(self.xpath_root + u'/t:RequiredAttendees/t:Attendee', namespaces=soap_request.NAMESPACES)
     for attendee in required_attendees:
       attendee_properties = self.service._xpath_to_dict(element=attendee, property_map=property_map, namespace_map=soap_request.NAMESPACES)
       attendee_properties[u'required'] = True
@@ -346,7 +448,7 @@ class Exchange2010CalendarEvent(BaseExchangeCalendarEvent):
 
       result.append(attendee_properties)
 
-    optional_attendees = response.xpath(u'//m:Items/t:CalendarItem/t:OptionalAttendees/t:Attendee', namespaces=soap_request.NAMESPACES)
+    optional_attendees = response.xpath(self.xpath_root + u'/t:OptionalAttendees/t:Attendee', namespaces=soap_request.NAMESPACES)
 
     for attendee in optional_attendees:
       attendee_properties = self.service._xpath_to_dict(element=attendee, property_map=property_map, namespace_map=soap_request.NAMESPACES)
