@@ -5,5 +5,5 @@ Licensed under the Apache License, Version 2.0 (the "License");?you may not use
 Unless required by applicable law or agreed to in writing, software?distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 """
 FAKE_EXCHANGE_URL = u'http://10.0.0.0/nothing'
-FAKE_EXCHANGE_USERNAME = u'nobody'
+FAKE_EXCHANGE_USERNAME = u'FAKEDOMAIN\\nobody'
 FAKE_EXCHANGE_PASSWORD = u'totallyfake'
