@@ -5,26 +5,27 @@ Licensed under the Apache License, Version 2.0 (the "License");?you may not use
 Unless required by applicable law or agreed to in writing, software?distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 """
 import httpretty
-from nose.tools import eq_, raises
+import unittest
+from pytest import raises
 from pyexchange.connection import ExchangeNTLMAuthConnection
 from pyexchange.exceptions import *
 
+
 from .fixtures import *
 
 
-class Test_ExchangeNTLMAuthConnection(object):
+class Test_ExchangeNTLMAuthConnection(unittest.TestCase):
 
   service = None
 
   @classmethod
-  def setUpAll(cls):
+  def setUpClass(cls):
 
     cls.connection=ExchangeNTLMAuthConnection(url=FAKE_EXCHANGE_URL,
                                               username=FAKE_EXCHANGE_USERNAME,
                                               password=FAKE_EXCHANGE_PASSWORD)
 
 
-  @raises(FailedExchangeException)
   @httpretty.activate
   def test_requesting_an_event_id_that_doest_exist_throws_error(self):
 
@@ -32,5 +33,6 @@ class Test_ExchangeNTLMAuthConnection(object):
                            status=401,
                            body="", )
 
-    self.connection.send(b'yo')
+    with raises(FailedExchangeException):
+      self.connection.send(b'yo')
 
